@@ -4,4 +4,6 @@ from .MQTT import *
 from .Colors import *
 from .SetupTools import *
 from .Config import *
-from .Exiter import *
\ No newline at end of file
+from .Exiter import *
+from .Applications import *
+from .Database import *
\ No newline at end of file
